# TODO

## Features

### Important

- create switch method to determin where to getinfo from


- create logger in Supportkeeper


### Unimportant

### Maybe

## Bugs

### Important

### Unimportant

### Maybe

## Tests

### Important

- Test cli scripts

### Unimportant

### Maybe

## Misc

### Important

### Unimportant

### Maybe

- create gui version of cli scripts